@@ -11,12 +11,27 @@ def save_model(model, model_name):
     model.save_weights(f'{model_name}_weights.h5')
 
 
-def load_model(model_name):
+def load_model(model_name, custom_objects=None):
+    """[summary]
+
+
+    Args:
+        model_name ([type]): [description]
+        custom_objects ([dict], optional): Dictionary to pass to tf.keras.models.model_from_json.
+        Use it to specify things like LeakyReLU.
+        See: https://stackoverflow.com/questions/55364954/keras-load-model-cant-recognize-tensorflows-activation-functions
+        See: https://github.com/tensorflow/tfjs/issues/1093
+        Defaults to None.
+
+    Returns:
+        [type]: [description]
+    """
     # Reading the model from JSON file
     with open(f'{model_name}.json', 'r') as json_file:
         json_savedModel = json_file.read()
     # load the model architecture
-    model = tf.keras.models.model_from_json(json_savedModel)
+    model = tf.keras.models.model_from_json(
+        json_savedModel, custom_objects=custom_objects)
     # model.summary()
     model.load_weights(f'{model_name}_weights.h5')
     return model
